package cl.axg.hls_player;

import android.content.Context;
import android.content.Intent;
import android.net.Uri;
import android.os.Bundle;

import android.text.TextUtils;
import android.util.Log;
import androidx.annotation.NonNull;

import io.flutter.app.FlutterActivity;
import io.flutter.embedding.engine.FlutterEngine;
import io.flutter.embedding.engine.FlutterEngineCache;
import io.flutter.embedding.engine.dart.DartExecutor;
import io.flutter.embedding.engine.plugins.FlutterPlugin;
import io.flutter.embedding.engine.plugins.activity.ActivityAware;
import io.flutter.embedding.engine.plugins.activity.ActivityPluginBinding;
import io.flutter.plugin.common.BinaryMessenger;
import io.flutter.plugin.common.EventChannel;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;
import io.flutter.plugin.common.PluginRegistry;
import io.flutter.plugin.common.PluginRegistry.Registrar;
import java.util.ArrayList;

/** HlsPlayerPlugin */
public class HlsPlayerPlugin implements  MethodCallHandler, FlutterPlugin  {

    private Context applicationContext;
    private MethodChannel methodChannel;
    private EventChannel eventChannel;

    /** Plugin registration. */
    public static void registerWith(PluginRegistry.Registrar registrar) {
        final HlsPlayerPlugin instance = new HlsPlayerPlugin();
        instance.onAttachedToEngine(registrar.context(), registrar.messenger());
    }

    @Override
    public void onAttachedToEngine(FlutterPluginBinding binding) {
        onAttachedToEngine(binding.getApplicationContext(), binding.getBinaryMessenger());
    }

    private void onAttachedToEngine(Context applicationContext, BinaryMessenger messenger) {
        this.applicationContext = applicationContext;
        methodChannel = new MethodChannel(messenger, "hls_player");
        methodChannel.setMethodCallHandler(this);
    }

    @Override
    public void onDetachedFromEngine(FlutterPluginBinding binding) {
        applicationContext = null;
        methodChannel.setMethodCallHandler(null);
        methodChannel = null;
        eventChannel.setStreamHandler(null);
        eventChannel = null;
    }

    @Override
    public void onMethodCall(MethodCall call, Result result) {
           if (call.method.equals("initializeVideo")) {
                    String url  = call.argument("url");
                    if(TextUtils.isEmpty(url)){
            
                         result.error( "Argumento invalido", "ha olvidado el parametro url", "se espera 1 string en formato URL de video HLS");
                         return;
                    } 

                        try{
                                Intent browserIntent = new Intent(this.applicationContext, MainActivity.class);
                                browserIntent.setFlags(Intent.FLAG_ACTIVITY_NEW_TASK);
                                browserIntent.putExtra("url", url);
                            this.applicationContext.startActivity(browserIntent);
                        }catch (Exception e){
                             Log.d("Catch error",e.getMessage());
                                    result.error( "Catch error", e.getMessage(),null);
                                    return;
                        }

        } 
        if (call.method.equals("initializeZapping")) {


   try{
                       String  canales  = call.argument("canales");
                       int  playVideoAtIndex  = call.argument("playVideoAtIndex");
                       boolean  isSearchingItem  = call.argument("isSearchingItem");
                       String  urlEPG  = call.argument("urlEPG");

                                Intent browserIntent = new Intent(this.applicationContext, ZappingActivity.class);
                                browserIntent.setFlags(Intent.FLAG_ACTIVITY_NEW_TASK);
                                browserIntent.putExtra("canales", canales);
                                browserIntent.putExtra("playVideoAtIndex", playVideoAtIndex);
                                browserIntent.putExtra("isSearchingItem", isSearchingItem);
                                   browserIntent.putExtra("urlEPG", urlEPG);

                                this.applicationContext.startActivity(browserIntent);
                                    result.success(canales);

                    }catch (Exception e)
                    {
                             Log.d("hls_player",e.getMessage());
                                    result.error( "Catch error", e.getMessage(),null);
                                    return;
                    } 
        }
           if (call.method.equals("getVideoLink")) {
                final  String getCurrentVideoLink = ZappingActivity.canales.get(ZappingActivity.playVideoAtIndex).getLinkReproductor();
                Log.d("hls_player", "video que se esta reproduciendo: "+getCurrentVideoLink);
                                    result.success(getCurrentVideoLink);
                      

        }
        if (call.method.equals("closeZapping")) {
            Log.d("hls_player","close Zapping");
            ZappingActivity.activity.finish();
            result.success(true);
        }
        if (call.method.equals("closeBuscador")) {
            Log.d("hls_player","close Buscador");
            MainActivity.activity.finish();
            result.success(true);
        }
        else {
            result.notImplemented();
        }
    }

}
