package cl.axg.exoplayer.srt_protocolo;

import com.google.android.exoplayer2.upstream.BaseDataSource;

import android.net.Uri;
import android.util.Pair;

import com.google.android.exoplayer2.upstream.DataSpec;
import io.github.thibaultbee.srtdroid.enums.SockOpt;
import io.github.thibaultbee.srtdroid.enums.Transtype;
import io.github.thibaultbee.srtdroid.models.Socket;

import java.io.IOException;
import java.util.LinkedList;
import java.util.Queue;

import kotlin.jvm.internal.Intrinsics;
import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;




public final class SrtLiveStreamDataSource extends BaseDataSource {

    public static final int PAYLOAD_SIZE = 1316;
    private Socket socket;
    private final Queue byteQueue;
    private final String srtUrl;
    private final int port;
    private final String passPhrase;

    public SrtLiveStreamDataSource(@NotNull String srtUrl, int port, @Nullable String passPhrase) {
        super(true);
        Intrinsics.checkNotNullParameter(srtUrl, "srtUrl");
        this.srtUrl = srtUrl;
        this.port = port;
        this.passPhrase = passPhrase;
        this.byteQueue = (Queue)(new LinkedList());
    }
    public long open(@NotNull DataSpec dataSpec) {
        Intrinsics.checkNotNullParameter(dataSpec, "dataSpec");
        this.socket = new Socket();
        Socket var10000 = this.socket;
        if (var10000 != null) {
            var10000.setSockFlag(SockOpt.TRANSTYPE, Transtype.LIVE);
        }

        var10000 = this.socket;
        if (var10000 != null) {
            var10000.setSockFlag(SockOpt.PAYLOADSIZE, 1316);
        }

        if (this.passPhrase != null) {
            var10000 = this.socket;
            if (var10000 != null) {
                var10000.setSockFlag(SockOpt.PASSPHRASE, this.passPhrase);
            }
        }

        var10000 = this.socket;
        if (var10000 != null) {
            var10000.connect(this.srtUrl, this.port);
        }

        return (long)-1;
    }

    public int read(@NotNull byte[] buffer, int offset, int length) {
        Intrinsics.checkNotNullParameter(buffer, "buffer");
        if (length == 0) {
            return 0;
        } else {
            int bytesReceived = 0;
            if (this.socket == null) {
                try {
                    throw (Throwable)(new IOException("Couldn't read bytes at offset: " + offset));
                } catch (Throwable e) {
                    throw new RuntimeException(e);
                }
            } else {
                Socket var10000 = this.socket;
                Intrinsics.checkNotNull(var10000);
                Pair received = var10000.recv(1316);
                byte[] var8 = (byte[])received.second;
                int var9 = var8.length;

                int var6;
                for(int var7 = 0; var7 < var9; ++var7) {
                    var6 = var8[var7];
                    this.byteQueue.offer(Byte.valueOf((byte)var6));
                }

                for(var6 = 0; var6 < length; ++var6) {
                   //int var11 = false;
                    Byte var12 = (Byte)this.byteQueue.poll();
                    if (var12 != null) {
                        buffer[var6 + offset] = var12;
                        ++bytesReceived;
                    }
                }

                return bytesReceived;
            }
        }
    }

    @Nullable
    public Uri getUri() {
        return Uri.parse("srt://" + this.srtUrl + ':' + this.port);
    }

    public void close() {
        Socket var10000 = this.socket;
        if (var10000 != null) {
            var10000.close();
        }

        this.socket = null;
    }

}
